pub struct BigLinearUair<R, P>(/* private fields */);Trait Implementations
Sourceimpl<R: Clone, P: Clone> Clone for BigLinearUair<R, P>
impl<R: Clone, P: Clone> Clone for BigLinearUair<R, P>
Sourcefn clone(&self) -> BigLinearUair<R, P>
fn clone(&self) -> BigLinearUair<R, P>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R, P> GenerateRandomTrace<32> for BigLinearUair<R, P>
impl<R, P> GenerateRandomTrace<32> for BigLinearUair<R, P>
Sourceimpl<R, P> Uair for BigLinearUair<R, P>
impl<R, P> Uair for BigLinearUair<R, P>
Sourcetype Ideal = RotationIdeal<R, 1>
type Ideal = RotationIdeal<R, 1>
The ideal type the AIR operates with.
Since a
ConstraintBuilder is “opaque” for a Uair
a Uair has to have a means to create ideals
so ideals are fixed by this associated types.
At the constrain* methods a Uair is given
a way to convert its own ideals into builder’s ideals
via the FromRef trait.Sourcetype FqIdeal = ImpossibleIdeal
type FqIdeal = ImpossibleIdeal
The ideal type for $F_{q_i}[X]$-constraints emitted via
[
ConstraintBuilder::assert_in_fq_ideal]. UAIRs that do not declare
any primes should set this to [ideal::ImpossibleIdeal].Sourcetype Scalar = DensePolynomial<R, 32>
type Scalar = DensePolynomial<R, 32>
The type of scalars of the UAIR.
For now, we assume they are of the type “arbitrary polynomials”.
Sourcetype Prime = P
type Prime = P
Type of primes defined in signature. Must be compatible with the field
type we’re using.
Sourcefn constrain_general<C, B, FromR, MulByScalar, IFromR, IFqFromR>(
b: &mut B,
expr_cfg: &C,
up: TraceRow<'_, C::Element>,
down: TraceRow<'_, C::Element>,
_from_ref: FromR,
_mbs: MulByScalar,
ideal_from_ref: IFromR,
_fq_ideal_from_ref: IFqFromR,
)
fn constrain_general<C, B, FromR, MulByScalar, IFromR, IFqFromR>( b: &mut B, expr_cfg: &C, up: TraceRow<'_, C::Element>, down: TraceRow<'_, C::Element>, _from_ref: FromR, _mbs: MulByScalar, ideal_from_ref: IFromR, _fq_ideal_from_ref: IFqFromR, )
A general method for describing constraints. Read more