pub struct BigLinearUairWithPublicInput<R, P>(/* private fields */);Trait Implementations
Sourceimpl<R: Clone, P: Clone> Clone for BigLinearUairWithPublicInput<R, P>
impl<R: Clone, P: Clone> Clone for BigLinearUairWithPublicInput<R, P>
Sourcefn clone(&self) -> BigLinearUairWithPublicInput<R, P>
fn clone(&self) -> BigLinearUairWithPublicInput<R, P>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R, P> GenerateRandomTrace<32> for BigLinearUairWithPublicInput<R, P>
impl<R, P> GenerateRandomTrace<32> for BigLinearUairWithPublicInput<R, P>
type PolyCoeff = <BigLinearUair<R, P> as GenerateRandomTrace<32>>::PolyCoeff
type Int = <BigLinearUair<R, P> as GenerateRandomTrace<32>>::Int
fn generate_random_trace<G: Rng + ?Sized>( num_vars: usize, rng: &mut G, ) -> UairTrace<'static, Self::PolyCoeff, Self::Int, 32, 32>
Sourceimpl<R, P> Uair for BigLinearUairWithPublicInput<R, P>
impl<R, P> Uair for BigLinearUairWithPublicInput<R, P>
Sourcetype Ideal = <BigLinearUair<R, P> as Uair>::Ideal
type Ideal = <BigLinearUair<R, P> as Uair>::Ideal
The ideal type the AIR operates with.
Since a
ConstraintBuilder is “opaque” for a Uair
a Uair has to have a means to create ideals
so ideals are fixed by this associated types.
At the constrain* methods a Uair is given
a way to convert its own ideals into builder’s ideals
via the FromRef trait.Sourcetype FqIdeal = <BigLinearUair<R, P> as Uair>::FqIdeal
type FqIdeal = <BigLinearUair<R, P> as Uair>::FqIdeal
The ideal type for $F_{q_i}[X]$-constraints emitted via
[
ConstraintBuilder::assert_in_fq_ideal]. UAIRs that do not declare
any primes should set this to [ideal::ImpossibleIdeal].Sourcetype Scalar = <BigLinearUair<R, P> as Uair>::Scalar
type Scalar = <BigLinearUair<R, P> as Uair>::Scalar
The type of scalars of the UAIR.
For now, we assume they are of the type “arbitrary polynomials”.
Sourcetype Prime = <BigLinearUair<R, P> as Uair>::Prime
type Prime = <BigLinearUair<R, P> as Uair>::Prime
Type of primes defined in signature. Must be compatible with the field
type we’re using.
Sourcefn constrain_general<C, B, FromR, MulByScalar, IFromR, IFqFromR>(
b: &mut B,
expr_cfg: &C,
up: TraceRow<'_, C::Element>,
down: TraceRow<'_, C::Element>,
from_ref: FromR,
mbs: MulByScalar,
ideal_from_ref: IFromR,
fq_ideal_from_ref: IFqFromR,
)
fn constrain_general<C, B, FromR, MulByScalar, IFromR, IFqFromR>( b: &mut B, expr_cfg: &C, up: TraceRow<'_, C::Element>, down: TraceRow<'_, C::Element>, from_ref: FromR, mbs: MulByScalar, ideal_from_ref: IFromR, fq_ideal_from_ref: IFqFromR, )
A general method for describing constraints. Read more