pub struct TestUairAffineVirtual<R, P, const NUM_PUBLIC_BINARY: usize>(/* private fields */);Expand description
UAIR fixture for affine virtual booleanity targets while an independent F_q constraint family is present.
For public e and witness g, the witnesses u_not = (!e) & g and
u_and = e & g are characterized by the paper’s two Ch membership
expressions
(1_32 - e) + g - 2u_not in {0, 1}^{<32}[X]
e + g - 2u_and in {0, 1}^{<32}[X].Trait Implementations
Sourceimpl<R: Clone, P: Clone, const NUM_PUBLIC_BINARY: usize> Clone for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
impl<R: Clone, P: Clone, const NUM_PUBLIC_BINARY: usize> Clone for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
Sourcefn clone(&self) -> TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
fn clone(&self) -> TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R: Debug, P: Debug, const NUM_PUBLIC_BINARY: usize> Debug for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
impl<R: Debug, P: Debug, const NUM_PUBLIC_BINARY: usize> Debug for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
Sourceimpl<R, P, const NUM_PUBLIC_BINARY: usize> GenerateRandomTrace<32> for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
impl<R, P, const NUM_PUBLIC_BINARY: usize> GenerateRandomTrace<32> for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
Sourceimpl<R, P, const NUM_PUBLIC_BINARY: usize> Uair for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
impl<R, P, const NUM_PUBLIC_BINARY: usize> Uair for TestUairAffineVirtual<R, P, NUM_PUBLIC_BINARY>
Sourcetype Ideal = RotationIdeal<R, 1>
type Ideal = RotationIdeal<R, 1>
The ideal type the AIR operates with.
Since a
ConstraintBuilder is “opaque” for a Uair
a Uair has to have a means to create ideals
so ideals are fixed by this associated types.
At the constrain* methods a Uair is given
a way to convert its own ideals into builder’s ideals
via the FromRef trait.Sourcetype FqIdeal = RotationIdeal<R, 1>
type FqIdeal = RotationIdeal<R, 1>
The ideal type for $F_{q_i}[X]$-constraints emitted via
[
ConstraintBuilder::assert_in_fq_ideal]. UAIRs that do not declare
any primes should set this to [ideal::ImpossibleIdeal].Sourcetype Scalar = DensePolynomial<R, 32>
type Scalar = DensePolynomial<R, 32>
The type of scalars of the UAIR.
For now, we assume they are of the type “arbitrary polynomials”.
Sourcetype Prime = P
type Prime = P
Type of primes defined in signature. Must be compatible with the field
type we’re using.
Sourcefn constrain_general<C, B, FromR, MulByScalar, IFromR, IFqFromR>(
b: &mut B,
expr_cfg: &C,
up: TraceRow<'_, C::Element>,
_down: TraceRow<'_, C::Element>,
_from_ref: FromR,
_mbs: MulByScalar,
ideal_from_ref: IFromR,
fq_ideal_from_ref: IFqFromR,
)
fn constrain_general<C, B, FromR, MulByScalar, IFromR, IFqFromR>( b: &mut B, expr_cfg: &C, up: TraceRow<'_, C::Element>, _down: TraceRow<'_, C::Element>, _from_ref: FromR, _mbs: MulByScalar, ideal_from_ref: IFromR, fq_ideal_from_ref: IFqFromR, )
A general method for describing constraints. Read more