pub struct BigLinearUair<R>(/* private fields */);Trait Implementations
Sourceimpl<R: Clone> Clone for BigLinearUair<R>
impl<R: Clone> Clone for BigLinearUair<R>
Sourcefn clone(&self) -> BigLinearUair<R>
fn clone(&self) -> BigLinearUair<R>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R: Debug> Debug for BigLinearUair<R>
impl<R: Debug> Debug for BigLinearUair<R>
Sourceimpl<R> GenerateRandomTrace<32> for BigLinearUair<R>
impl<R> GenerateRandomTrace<32> for BigLinearUair<R>
Sourceimpl<R> Uair for BigLinearUair<R>
impl<R> Uair for BigLinearUair<R>
Sourcetype Ideal = RotationIdeal<R, 1>
type Ideal = RotationIdeal<R, 1>
The ideal type the AIR operates with.
Since a
ConstraintBuilder is “opaque” for a Uair
a Uair has to have a means to create ideals
so ideals are fixed by this associated types.
At the constrain* methods a Uair is given
a way to convert its own ideals into builder’s ideals
via the FromRef trait.Sourcetype Scalar = DensePolynomial<R, 32>
type Scalar = DensePolynomial<R, 32>
The type of scalars of the UAIR.
For now, we assume they are of
the type “arbitrary polynomials”.
Sourcefn signature() -> UairSignature
fn signature() -> UairSignature
Signature of the UAIR. Read more
Sourcefn constrain_general<B, FromR, MulByScalar, IFromR>(
b: &mut B,
up: TraceRow<'_, B::Expr>,
down: TraceRow<'_, B::Expr>,
_from_ref: FromR,
_mbs: MulByScalar,
ideal_from_ref: IFromR,
)
fn constrain_general<B, FromR, MulByScalar, IFromR>( b: &mut B, up: TraceRow<'_, B::Expr>, down: TraceRow<'_, B::Expr>, _from_ref: FromR, _mbs: MulByScalar, ideal_from_ref: IFromR, )
A general method for describing constraints. Read more
fn constrain<B>(
b: &mut B,
up: TraceRow<'_, <B as ConstraintBuilder>::Expr>,
down: TraceRow<'_, <B as ConstraintBuilder>::Expr>,
)where
B: ConstraintBuilder,
<B as ConstraintBuilder>::Expr: FromRef<Self::Scalar> + for<'b> MulByScalar<&'b Self::Scalar>,
<B as ConstraintBuilder>::Ideal: FromRef<Self::Ideal>,