pub struct BigLinearUairWithPublicInput<R>(/* private fields */);Trait Implementations
Sourceimpl<R: Clone> Clone for BigLinearUairWithPublicInput<R>
impl<R: Clone> Clone for BigLinearUairWithPublicInput<R>
Sourcefn clone(&self) -> BigLinearUairWithPublicInput<R>
fn clone(&self) -> BigLinearUairWithPublicInput<R>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R: Debug> Debug for BigLinearUairWithPublicInput<R>
impl<R: Debug> Debug for BigLinearUairWithPublicInput<R>
Sourceimpl<R> GenerateRandomTrace<32> for BigLinearUairWithPublicInput<R>
impl<R> GenerateRandomTrace<32> for BigLinearUairWithPublicInput<R>
type PolyCoeff = <BigLinearUair<R> as GenerateRandomTrace<32>>::PolyCoeff
type Int = <BigLinearUair<R> as GenerateRandomTrace<32>>::Int
fn generate_random_trace<Rng: RngCore + ?Sized>( num_vars: usize, rng: &mut Rng, ) -> UairTrace<'static, Self::PolyCoeff, Self::Int, 32>
Sourceimpl<R> Uair for BigLinearUairWithPublicInput<R>
impl<R> Uair for BigLinearUairWithPublicInput<R>
Sourcetype Ideal = <BigLinearUair<R> as Uair>::Ideal
type Ideal = <BigLinearUair<R> as Uair>::Ideal
The ideal type the AIR operates with.
Since a
ConstraintBuilder is “opaque” for a Uair
a Uair has to have a means to create ideals
so ideals are fixed by this associated types.
At the constrain* methods a Uair is given
a way to convert its own ideals into builder’s ideals
via the FromRef trait.Sourcetype Scalar = <BigLinearUair<R> as Uair>::Scalar
type Scalar = <BigLinearUair<R> as Uair>::Scalar
The type of scalars of the UAIR.
For now, we assume they are of
the type “arbitrary polynomials”.
Sourcefn signature() -> UairSignature
fn signature() -> UairSignature
Signature of the UAIR. Read more
Sourcefn constrain_general<B, FromR, MulByScalar, IFromR>(
b: &mut B,
up: TraceRow<'_, B::Expr>,
down: TraceRow<'_, B::Expr>,
from_ref: FromR,
mbs: MulByScalar,
ideal_from_ref: IFromR,
)
fn constrain_general<B, FromR, MulByScalar, IFromR>( b: &mut B, up: TraceRow<'_, B::Expr>, down: TraceRow<'_, B::Expr>, from_ref: FromR, mbs: MulByScalar, ideal_from_ref: IFromR, )
A general method for describing constraints. Read more
fn constrain<B>(
b: &mut B,
up: TraceRow<'_, <B as ConstraintBuilder>::Expr>,
down: TraceRow<'_, <B as ConstraintBuilder>::Expr>,
)where
B: ConstraintBuilder,
<B as ConstraintBuilder>::Expr: FromRef<Self::Scalar> + for<'b> MulByScalar<&'b Self::Scalar>,
<B as ConstraintBuilder>::Ideal: FromRef<Self::Ideal>,